# Model Parts

## ::: dreem.models.VisualEncoder

## ::: dreem.models.Transformer

### ::: dreem.models.transformer.TransformerEncoder

#### ::: dreem.models.transformer.TransformerEncoderLayer

##### ::: dreem.models.Embedding

### ::: dreem.models.transformer.TransformerDecoder

#### ::: dreem.models.transformer.TransformerDecoderLayer

## ::: dreem.models.attention_head.ATTWeightHead

## ::: dreem.models.mlp.MLP